# skale-py

Skale client tools.
Python implementation which is used in the blockchain-node and sla-agent projects.


##### Install local version (with hot reload)

```
pip install -e .
```

### Build and publish lib

```bash
bash build_and_publish.sh major/minor/patch custom/test/srv/aws/prod
```

### Versioning

The version format for this repo is `{major}.{minor}.{patch}` for stable, and `{major}.{minor}.{patch}-{stage}.{devnum}` for unstable (stage can be `alpha` or `beta`).

For more details see: https://semver.org/


##### Fix for scrypt error
https://github.com/ethereum/web3.py/issues/751